Commit in reactos/subsys/win32k/ntuser on MAIN
window.c+3-31.229 -> 1.230
take back changes to window styles, they broke our gui consoles

reactos/subsys/win32k/ntuser
window.c 1.229 -> 1.230
diff -u -r1.229 -r1.230
--- window.c	10 May 2004 17:07:18 -0000	1.229
+++ window.c	10 May 2004 19:23:37 -0000	1.230
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-/* $Id: window.c,v 1.229 2004/05/10 17:07:18 weiden Exp $
+/* $Id: window.c,v 1.230 2004/05/10 19:23:37 weiden Exp $
  *
  * COPYRIGHT:        See COPYING in the top level directory
  * PROJECT:          ReactOS kernel
@@ -1634,9 +1634,9 @@
   
   if(!(WindowObject->Style & (WS_POPUP | WS_CHILD)))
   {
     /* Automatically assign the overlapped window style. Also always
        clip siblings for overlapped windows. */
-    WindowObject->Style |= (WS_OVERLAPPEDWINDOW | WS_CLIPSIBLINGS);
+    WindowObject->Style |= (WS_CAPTION | WS_BORDER | WS_CLIPSIBLINGS);
   }
   
   /* create system menu */
@@ -1634,9 +1634,9 @@
   if(!(WindowObject->Style & (WS_POPUP | WS_CHILD)))
   {
-    /* Automatically assign the overlapped window style. Also always
+    /* Automatically assign the caption and border style. Also always
        clip siblings for overlapped windows. */
CVSspam 0.2.8